;-------------------------------------------------------------
;  Filelib: file/folder operations functions
;		by the Doors Team
;	xvassor@mail.dotcom.fr   or	deucalion@mail.dotcom.fr
;		http://doorshome.home.ml.org
;-------------------------------------------------------------

;NOTE: If you want to use these functions on a folder
; you have to do: "moveq.w #$08,d0"
;NOTE2: the index of a file(or a folder) is its place in the 
;file(or folder) list.
;for example if you have the following file list:

;	filelib
;	graphlib
;	shell
;	userlib

;Then the index of filelib is 0, the index of graphlib is 1...


filelib::sortlist 	equ	filelib@0000
;--------------------------------------------------------------
;sortlist(list handle)
;
;   Sorts file/folder list d0 in alphabetical order
;
;Input:	d0.w = file/folder list handle
;
;Output: nothing
;
;	NO REGISTERS DESTROYED
;--------------------------------------------------------------

filelib::delete		equ	filelib@0001
;--------------------------------------------------------------
;delete(folder,file/folder)
;
;    Deletes the file/folder d1 in folder d0
;
;Input: d0.w = folder handle
;	d1.w = file/folder index
;
;Output: nothing
;	NO REGISTERS DESTROYED
;--------------------------------------------------------------

filelib::copy		equ	filelib@0002
;--------------------------------------------------------------
;copy(folder,file,newfolder)
;
;   Copies the file d1 in folder d0 to folder d2
;
;Input:	d0.w = source folder handle
;	d1.w = file index
;	d2.w = dest folder handle
;
;Output:nothing
;	NO OTHER REGISTERS DESTROYED
;--------------------------------------------------------------

filelib::move		equ	filelib@0003
;--------------------------------------------------------------
;move(folder,file,newfolder)
;
;   Moves the file d1 in folder d0 to folder d2
;
;Input:	d0.w = source folder handle
;	d1.w = file index
;	d2.w = dest folder handle
;
;Output:nothing
;	NO REGISTERS DESTROYED
;
;--------------------------------------------------------------

filelib::rename		equ	filelib@0004
;--------------------------------------------------------------
;rename(folder,file/folder,newname)
;
;    Renames the file/folder d1 in folder d0 with new name a0
;
;Input: d0.w = folder handle
;	d1.w = file/folder index
;	a0.l = adress of the new name
;
;Output: nothing
;	NO REGISTERS DESTROYED
;--------------------------------------------------------------

filelib::createfolder	equ	filelib@0005
;--------------------------------------------------------------
;createfolder(name)
;
;	Creates a new folder
;
;Input: a0.l = name of the folder
;
;Output: nothing
;
;	NO REGISTERS DESTROYED
;--------------------------------------------------------------

filelib::protect	equ	filelib@0006
;-------------------------------------------------------------
;protect(folder,file/folder)
;
;   Protects the file/folder d1 in folder d0 so that this file
; is unreacheable in TI OS and quite invisible in FARGO programs
;   You can access it again only with the Doors shell
;
;Input: d0.w = folder handle
;	d1.w = file/folder index
;
;Output: nothing
;	NO REGISTERS DESTROYED
;--------------------------------------------------------------

filelib::hide		equ	filelib@0007
;--------------------------------------------------------------
;hide(folder,file/folder)
;
;	used on a file, this function makes it disappear from TIOS
;	used on a folder, this function hides it in the Var-Link
;   But the file is always appears in FARGO programs
;Input:	d0.w = folder handle
;	d1.w = file/folder index
;
;Output: nothing
;--------------------------------------------------------------

filelib::unhide		equ	filelib@0008
;--------------------------------------------------------------
;unhide(folder,file/folder)
;
;	Cancelles the effects of hide
;
;Input:	d0.w = folder handle
;	d1.w = file/folder index
;
;Output: nothing
;--------------------------------------------------------------

filelib::hdltoindex	equ	filelib@0009
;--------------------------------------------------------------
;hdltoindex(folder,file/folder handle)
;
;   Returns the index of the file/folder given its handle
;   It searches in folder d0
;   This function is very useful if you want to use filelib and you only 
;   possess the handle of a file
;
;Input:	d0.w = folder handle where you search
;	d2.w =file/folder handle to search
;
;Output: d1.w = file/folder index
;	d0.l = 0 -> the handle wasn't found
;	NO OTHER REGISTERS DESTROYED
;--------------------------------------------------------------


filelib::gettype	equ	filelib@000A
;--------------------------------------------------------------
;gettype(folder,file)
;
;	returns the type of the file d1 in folder d0
;
;Input: d0.w = folder handle
;	d1.w = file index
;
;Output: d2.w = type of the file
;
;The values for d2 are:
;
;ASM	->0
;LIB	->1
;PROG	->2
;FUNC	->3
;MAT	->4
;LIST	->5
;MACR	->6
;TEXT	->7
;STR	->8
;DATA	->9
;FIG	->10
;PIC	->11
;GDB	->12
;EXPR	->13
;
;	NO OTHER REGISTERS DESTROYED
;--------------------------------------------------------------